@@ -7,7 +7,7 @@ class GameServer:
     CLIENT = Client.CLIENT
 
     @classmethod
-    def find_game_server(cls, service_id):
+    def find_by_id(cls, service_id):
         try:
             path = ['services', service_id, 'gameservers']
             data = GameServer.CLIENT.get(path=path)['data']['gameserver']
@@ -22,7 +22,7 @@ class GameServer:
             servs = GameServer.CLIENT.get(path='services')
             service_ids = [serv['id'] for serv in servs['data']['services']]
             for id in service_ids:
-                games.append(GameServer.find_game_server(id))
+                games.append(GameServer.find_by_id(id))
             return games
         except Exception as e:
             print(e)
